==> kibana-7.4.0-1-any.pkg.tar.xz: usr/share/kibana/src/legacy/core_plugins/dashboard_embeddable_container/public/np_ready/public/legacy.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.start = exports.setup = void 0;

var _new_platform = require("ui/new_platform");

var _saved_object_finder = require("ui/saved_objects/components/saved_object_finder");

var _exit_full_screen = require("ui/exit_full_screen");

var _ = require(".");

var _legacy = require("../../../../embeddable_api/public/np_ready/public/legacy");

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/* eslint-disable @kbn/eslint/no-restricted-paths */

/* eslint-enable @kbn/eslint/no-restricted-paths */
var pluginInstance = (0, _.plugin)({});
var setup = pluginInstance.setup(_new_platform.npSetup.core, {
  embeddable: _legacy.setup
});
exports.setup = setup;
var start = pluginInstance.start(_new_platform.npStart.core, {
  embeddable: _legacy.start,
  inspector: _new_platform.npStart.plugins.inspector,
  __LEGACY: {
    SavedObjectFinder: _saved_object_finder.SavedObjectFinder,
    ExitFullScreenButton: _exit_full_screen.ExitFullScreenButton
  }
});
exports.start = start;

==> kibana-7.5.0-1-any.pkg.tar.xz: usr/share/kibana/src/legacy/core_plugins/dashboard_embeddable_container/public/np_ready/public/legacy.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.start = exports.setup = void 0;

var _new_platform = require("ui/new_platform");

var _saved_object_finder = require("ui/saved_objects/components/saved_object_finder");

var _exit_full_screen = require("ui/exit_full_screen");

var _ = require(".");

var _legacy = require("../../../../embeddable_api/public/np_ready/public/legacy");

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/* eslint-disable @kbn/eslint/no-restricted-paths */

/* eslint-enable @kbn/eslint/no-restricted-paths */
var pluginInstance = (0, _.plugin)({});
var setup = pluginInstance.setup(_new_platform.npSetup.core, {
  embeddable: _legacy.setup,
  uiActions: _new_platform.npSetup.plugins.uiActions
});
exports.setup = setup;
var start = pluginInstance.start(_new_platform.npStart.core, {
  embeddable: _legacy.start,
  inspector: _new_platform.npStart.plugins.inspector,
  __LEGACY: {
    SavedObjectFinder: _saved_object_finder.SavedObjectFinder,
    ExitFullScreenButton: _exit_full_screen.ExitFullScreenButton
  },
  uiActions: _new_platform.npStart.plugins.uiActions
});
exports.start = start;
